# Presalytics Python Client

This package interfaces with the Presalytics.io APIs.  

For full API documentation and use, please go to [Documentation](https://presalytics.io/docs).  Quickstart templates and examples for this python client can be found at the [Python Client Subpage](https://presalytics.io/docs/guides/python-client/overview). 

## Requirements

Python 3.5+.  This client uses packages that are not yet compatible with python2.  If python2 compatiliity is needed for legacy applications, we'd love hear about your use case. The api client sub packages are python 2.7+ compatible.

## Installation

Install using the pip package tool 

''''bash
pip install presalytics
'''

